#
# spec file for package calamares
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://github.com/calamares/calamares/issues

%define _sover  3
Name:           calamares
Version:        3.1.10
Release:        lp150.1.33
Summary:        Installer from a live CD/DVD/USB to disk
Group:          System/Management
License:        GPL-3.0
Url:            http://calamares.io/
Source0:        https://github.com/%{name}/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz
# new generic branding.desc with explanations in comments
Source1:        branding.desc
Source2:        %{name}-rpmlintrc
# .desktop file customizations for openSUSE
Patch0:         %{name}-desktop-file.patch
# adjust some default settings (default shipped .conf files) for openSUSE and openSUSE based appliances
Patch1:         3.1.4-packages.conf.patch
Patch2:         2.4-bootloader.conf.patch
Patch3:         2.4-services.conf.patch
Patch4:         3.0-settings.conf.patch
Patch5:         3.1.4-unpackfs.conf.patch
Patch6:         3.1.2-configuring_autologin_in_sysconfig.patch
Patch7:         2.4-removeuser.conf.patch
Patch8:         3.1.1-welcome.conf.patch
Patch9:         3.1-show.qml.patch
Provides:       %{name}-libs%{_sover} = %{version}
Obsoletes:      %{name}-libs%{_sover} < %{version}
BuildRequires:  boost-devel >= 1.59.0
BuildRequires:  cmake >= 2.8.12
BuildRequires:  desktop-file-utils
BuildRequires:  extra-cmake-modules >= 0.0.13
BuildRequires:  gettext
# Calamares is only supported where live images (and GRUB) are. (rh#1171380)
BuildRequires:  grub2
BuildRequires:  hicolor-icon-theme
BuildRequires:  kconfig-devel
BuildRequires:  kcoreaddons-devel
BuildRequires:  ki18n-devel
BuildRequires:  kiconthemes-devel
BuildRequires:  kio-devel
BuildRequires:  kparts-devel
BuildRequires:  kpmcore-devel >= 3.0.2
BuildRequires:  kservice-devel
BuildRequires:  libatasmart-devel
BuildRequires:  libpolkit-qt5-1-devel
BuildRequires:  libqt5-qtbase-devel >= 5.4
BuildRequires:  libqt5-qtdeclarative-devel >= 5.4
BuildRequires:  libqt5-qtsvg-devel >= 5.4
BuildRequires:  libqt5-qttools-devel >= 5.4
BuildRequires:  libqt5-qtwebengine-devel >= 5.6
BuildRequires:  parted-devel
BuildRequires:  pkg-config
BuildRequires:  python3-devel >= 3.3
BuildRequires:  solid-devel
BuildRequires:  update-desktop-files
BuildRequires:  yaml-cpp-devel >= 0.5.1
Requires:       %name-branding >= 3
Requires:       NetworkManager
Requires:       console-setup
Requires:       coreutils
Requires:       dmidecode
Requires:       dosfstools
Requires:       dracut
Requires:       e2fsprogs
Requires:       gawk
Requires:       gptfdisk
Requires:       grub2
Requires:       kpmcore >= 3.0.2
Requires:       ntfsprogs
Requires:       os-prober
Requires:       parted
#Requires:       polkit
Requires:       python3
Requires:       rsync
Requires:       shadow
Requires:       squashfs
Requires:       systemd
Requires:       upower
Requires:       util-linux
Requires:       xdg-utils
Requires:       xkbutils
Requires:       zypper
Recommends:     btrfsprogs
Recommends:     hfsutils
Recommends:     jfsutils
Recommends:     ntfs-3g
Recommends:     reiserfs
Recommends:     xfsprogs
# C++11
# Calamares needs at least gcc5
%if %{?suse_version} == 1315
BuildRequires:  gcc5-c++
%else
BuildRequires:  gcc-c++ >= 5.0
%endif
%ifarch x86_64
# EFI currently only supported on x86_64
Requires:       grub2-efi
%endif

%description
Calamares is a distribution-independent installer framework, designed to install
from a live CD/DVD/USB environment to a hard disk. It includes a graphical
installation program based on Qt 5. Calamares can replace YaST2 Live Installer.

%package        webview
Summary:        Calamares webview module
Group:          System/Management
Requires:       %{name}%{?_isa} = %{version}

%description    webview
Optional webview module for the Calamares installer.


%package branding-upstream
Summary:        Branding for %{name}
Group:          System/Management
# This theme is nor pure upstream, nor specific to openSUSE,
# but is close to upstream
Supplements:    packageand(%name:branding-upstream)
#Supplements:    packageand(%%{name}:branding-openSUSE)
Conflicts:      otherproviders(%{name}-branding)
Provides:       %name-branding = %{version}
BuildArch:      noarch

%description branding-upstream
This package provides configuration files and "look and feel" for
Calamares installer. "Look and feel" files are simplified upstream files.
Meanwhile configuration files adopted to work with openSUSE and SUSE
based custom appliances.

%prep
%setup -q -n %{name}-%{version}
cp -f %{SOURCE1} src/branding/default/
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
# fix shebang 
find . -wholename "./src/modules/*/main.py" -exec sed -re "1s/^#\!\/usr\/bin\/env python3/#\!\/usr\/bin\/python3/" -i {} \;

%build
# Calamares needs at least gcc5
%if %{?suse_version} == 1315
export CC=gcc-5
export CXX=g++-5
%endif
%cmake_kf5 -d build --  -DCMAKE_INSTALL_PREFIX=%{_prefix} -DCMAKE_BUILD_TYPE:STRING="RelWithDebInfo"
make %{?_smp_mflags}

%install
# Calamares needs at least gcc5
%if %{?suse_version} == 1315
export CC=gcc-5
export CXX=g++-5
%endif
%kf5_makeinstall -C build
# if we don't want polkit (and you want use xdg-su instead)
rm -fr %{buildroot}%{_datadir}/polkit-1
# add executable bits
chmod +x %{buildroot}%{_libdir}/%{name}/modules/*/main.py
chmod +x %{buildroot}%{_libdir}/%{name}/modules/initramfscfg/encrypt_hook*
# own the local settings directories
mkdir -p %{buildroot}%{_sysconfdir}/%{name}/modules
mkdir -p %{buildroot}%{_sysconfdir}/%{name}/branding
# remove -devel files: calamares libraries are not expected to be used in other programs
rm -fr %{buildroot}%{_includedir}/lib%{name}/
rm -f  %{buildroot}%{_libdir}/lib%{name}.so
rm -f  %{buildroot}%{_libdir}/lib%{name}ui.so
rm -fr %{buildroot}%{_libdir}/cmake/Calamares/
%suse_update_desktop_file -r %{name} Qt System PackageManager

# localization
%find_lang %{name}-python
%find_lang %{name}-dummypythonqt

%post
%desktop_database_post
/sbin/ldconfig

%postun
%desktop_database_postun
/sbin/ldconfig

# Non-standart placement of files comes from upstream.
# Authors of Calamares already asked to install libs
# in the standard search path, see responses of authors in
# https://github.com/calamares/calamares/issues/729
%files -f %{name}-python.lang -f %{name}-dummypythonqt.lang
%doc LICENSE AUTHORS
%{_mandir}/*/*
%{_bindir}/%{name}
%{_sysconfdir}/%{name}/
%dir %{_datadir}/%{name}/
%{_datadir}/%{name}/qml/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
# if we want polkit (you can use xdg-su instead)
#%%{_datadir}/polkit-1/actions/com.github.%%{name}.%%{name}.policy
%{_libdir}/lib%{name}.so.*
%{_libdir}/lib%{name}ui.so.*
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/lib%{name}.so
%{_libdir}/%{name}/modules/
%exclude %{_libdir}/%{name}/modules/webview/

%files webview
%{_datadir}/%{name}/modules/webview.conf
%{_libdir}/%{name}/modules/webview/

%files branding-upstream
%doc LICENSE
%{_datadir}/%{name}/settings.conf
%dir %{_datadir}/%{name}/branding/
%{_datadir}/%{name}/branding/default/
%{_datadir}/%{name}/modules/
%exclude %{_datadir}/%{name}/modules/webview.conf

%changelog
* Mon Dec 18 2017 opensuse.lietuviu.kalba@gmail.com
- Update to Calamares 3.1.10:
  - fix bug then Python job-modules could not use pretty_name() for
    reporting the module status when the job was started.
  - The packages module can now be enabled, but then skipped if
    no internet is available (this is a preferred configuration for
    distro's which would like to install packages, but which are
    optional when there is no connection).
* Wed Dec  6 2017 opensuse.lietuviu.kalba@gmail.com
- Update to Calamares 3.1.9:
  - Fix bug in Netinstall corner cases: a hidden subgroup would be
    installed even when its parent was not selected, and a hidden
    subgroup could cause its parent to default to unselected.
  - The branding element ProductLogo is used as the logo, instead
    of the product icon.
* Thu Nov 23 2017 opensuse.lietuviu.kalba@gmail.com
- Update to Calamares 3.1.8:
  - Fix Netinstall crash if the returned netinstall-groups
    data was empty.
  - Fix regression were GeoIP data had been read twice.
  - Use more support code from KPMCore, instead of doing it
    ourselves.
* Thu Nov 23 2017 opensuse.lietuviu.kalba@gmail.com
- Update to Calamares 3.1.7 fixes two regressions introduced
  earlier in the 3.1 series (3.1.5 or before):
  - Netinstall was no longer compatible with the packages module,
    which prevented any users of netinstall from installing
    packages from online repositories.
  - The bootloader installation for EFI systems used the wrong
    name for the bootx64.efi (or bootia32.efi) files.
* Mon Oct 23 2017 opensuse.lietuviu.kalba@gmail.com
- Update to Calamares 3.1.6:
  - fixes two regressions introduced in 3.1.5
  - improving timezone selection in northern locations.
* Thu Oct 12 2017 opensuse.lietuviu.kalba@gmail.com
- Remove -devel subpackage: libraries are not intended to be used
  by other programs.
- Fix Python shebang in main.py files.
* Tue Oct  3 2017 opensuse.lietuviu.kalba@gmail.com
- Merge calamares and calamares-libs3 into one RPM package:
  Calamares' developers don't guarantee stable API or ABI,
  libraries are not intended to be used by other programs.
* Wed Sep 27 2017 opensuse.lietuviu.kalba@gmail.com
- Update to Calamares 3.1.5:
  - Python 3.4 is once again supported.
  - Improved reporting of dependencies in CMake.
  - Dozens of compilation warnings fixed up.
* Thu Sep  7 2017 opensuse.lietuviu.kalba@gmail.com
- Update to Calamares 3.1.4:
  - A race condition leading to crashes when starting Calamares
    has been resolved.
  - Packages module has been seriously revamped; it is now also
    translatable.
  - Translations in the partitioning module have been improved.
  - Encrypted swap is now correctly configured.
  - Minor visual improvements.
* Sun Sep  3 2017 opensuse.lietuviu.kalba@gmail.com
- Updated to Calamares 3.1.4 pre-release git version b22bd67:
  - Fix partitioning regressions in Calamares 3.1.2/3.1.3.
  - Drop calamares_crash_reporter.
* Fri Sep  1 2017 opensuse.lietuviu.kalba@gmail.com
- Drop 2.4-QT5.5-compat.patch: openSUSE Leap 42.1 no longer supported.
- Drop 3.1-users.conf.patch: no longer need to dissable autologin.
* Fri Sep  1 2017 opensuse.lietuviu.kalba@gmail.com
- Don't build calamares_crash_reporter for openSUSE Tumbleweed,
  otherwise entire building fails.
* Fri Sep  1 2017 opensuse.lietuviu.kalba@gmail.com
- Updated to Calamares 3.1.3:
  - Python jobs without a pretty_name() function – and that is the
    majority of them – could no longer be run.
  - The installation-is-done notification could hang Calamares when
    the installation failed.
- Update 2.4-unpackfs.conf.patch and rename it to
  3.1.3-unpackfs.conf.patch
* Fri Sep  1 2017 opensuse.lietuviu.kalba@gmail.com
- Updated to Calamares 3.1.2:
  - Translation updates.
  - Summary page now shows language and number-formats information.
  - The Quit and Done buttons now have a tooltip explaining what
    they will do.
  - At the end of the install process, a notification appears in
    the system notification area (generally a pop-up in the lower
    right-hand corner of the screen).
  - If installation fails, the system won’t reboot automatically on
    the last Calamares page.
  - Fat32 filesystems are now handled correctly even when misspelled.
  - Filesystem sizes are now shown with an MB suffix.
- Modify 3.1.2-SUSE_DM_-_add_special_case_configuring_autologin_in_sysconfig.patch
  and rename it to 3.1.2-configuring_autologin_in_sysconfig.patch
* Thu Aug  3 2017 opensuse.lietuviu.kalba@gmail.com
- Backport upstream patch to enable autologin configurations
  3.1.2-SUSE_DM_-_add_special_case_configuring_autologin_in_sysconfig.patch
* Sun Jul 30 2017 opensuse.lietuviu.kalba@gmail.com
- Updated to Calamares 3.1.1:
  - Improved salting for user passwords.
  - Crash on startup when no installation-devices are found has
    been fixed.
  - Support for very small screens (800x600) is improved.
  - Hostnames may be up to 63 characters in length, conforming to
    RFC1123 and various LDAP schemas.
  - System language, locale settings and keyboard are now guessed
    based on installer language and location.
  - Crashreporter added to release tarball.
* Mon Jun  5 2017 opensuse.lietuviu.kalba@gmail.com
- Provide branding package separately.
* Sun Jun  4 2017 opensuse.lietuviu.kalba@gmail.com
- Updated to Calamares 3.1.0.
  Upstream changes between Calamares 3.0.1 and 3.1.0:
  - improved package selection user interface;
  - support for disabling swap partition creation in automated
    partitioning;
  - double-click as a way to edit a partition in the manual
    partitioning view;
  - improved check for internet connection availability;
  - improved package manager handling, so a package operation which
    fails for a single package won’t block other packages;
  - various minor fixes.
  Upstream changes between Calamares 3.0.0 and 3.0.1:
  - fix for an issue in the users module, which could break login
    if the chosen password had non-Latin1 characters;
  - proper exception handling in the networkcfg module;
  - improved autologin configuration handling for sddm.
  Upstream changes between Calamares 2.4.6 and 3.0.0:
  - new optional PythonQt-based module interface.
  - dropped support for KPMcore 2;
  - countless fixes and improvements.
* Fri Jan 27 2017 opensuse.lietuviu.kalba@gmail.com
- Updated to Calamares 2.4.6:
  - fixed autologin handling for sddm in the displaymanager module;
  - improved build system files so module linkage defaults to
    private;
  - fixed an issue which caused the internet connection status to
    not be written to GlobalStorage;
  - added support for building the partition module with both
    KPMcore 2.2 and 3.0;
  - fixed a crash on startup in the webview module (if built with
    QtWebEngine);
  - fixed an issue in the partition module which could sometimes
    cause the legacy bootloader to be installed on the wrong disk;
  - fixed an issue in the users module to correctly disable the
    root password if configured to do so;
  - fixed an issue in the partition module to always set the
    correct flags for an EFI system partition.
* Fri Nov 25 2016 sb56637@gmail.com
- Updated to Calamares 2.4.5:
  - fixed a path handling issue which could sometimes occur when
    reusing an existing EFI system partition;
  - fixes and reliability improvements for the internet connection
    check in the welcome module;
  - fixed GRUB deployment with 32-bit UEFI firmware (note: this
    also affects some 64-bit systems which ship a 32-bit UEFI
    firmware);
  - fixed operating system detection for automatic dual boot setup
    in GRUB;
  - added Btrfs subvolumes setup for @ and @home in automated
    install modes (note: manual partitioning still doesn’t support
    Btrfs subvolumes, as this requires further work in both KPMcore
    and Calamares);
  - fixed a security issue which could happen when using manual
    partitioning to set up a system with an encrypted root
    partition, but with an unencrypted separate /boot partition.
* Tue Nov 22 2016 sb56637@gmail.com
- Updated to Calamares 2.4.4.
  Upstream changes between Calamares 2.4.3 and 2.4.4:
  - improved EFI system partition flag management (this removes a
    dependency on sgdisk);
  - improved parsing of SDDM configuration;
  - support for selecting visible groups by default in the
    netinstall module;
  - added option of updating the packages database before
    performing package operations;
  - added support for try_install and try_remove entries in the
    packages module configuration;
  - fixed potential failure in unpackfs module (caused by inability
    to write extended attributes to a filesystem which doesn’t
    support them).
  Upstream changes between Calamares 2.4.2 and 2.4.3:
  - added support for C++/Qt batch job plugins;
  - new dummycpp job module as an example for module developers;
  - added support for early LUKS unlocking with Debian initramfs
    (new initramfscfg module);
  - added support for early LUKS unlocking with Dracut
    (new dracutlukscfg module);
  - multiple fixes to /etc/crypttab handling to improve LUKS
    support on Debian and related distributions;
  - fixed user creation so it obeys the list of default groups
    for new users;
  - added Deepin support to the displaymanager module;
  - fixed an issue which could cause a failed install with LUKS
    if other LUKS partitions are already present.
* Mon Oct 17 2016 egeorget@openmailbox.org
- Rebasing partition.conf.patch (2.4 > 2.4.2)
* Mon Oct 17 2016 egeorget@openmailbox.org
- Updated to Calamares 2.4.2:
  - improved system requirements configuration checking;
  - fixed case-insensitive path handling when installing GRUB on
    VFAT filesystems;
  - removed dependency on chfn in the users module;
  - added support for Debian-style /etc/default/keyboard
    configuration as an option;
  - fixed an issue which could cause a failed install when
    resolv.conf is a broken symlink in the target rootfs;
  - fixed locale filtering for UTF-8 on Fedora and related
    distributions;
  - added support for disabling LUKS-related UI elements;
  - fixed an issue in the summary page, which caused the target
    root partition to be mislabeled in the UI.
* Tue Oct  4 2016 egeorget@openmailbox.org
- Modified 2.4-QT5.5-compat.patch to be a bit less hacky.
- Added Licence module to the default settings.
- Removed luksbootkeyfile, luksopenswaphookcfg and webview from default settings.
* Mon Oct  3 2016 egeorget@openmailbox.org
- Updated to Calamares 2.4.1.
- Rebased all patches.
- Splited calamares-opensuse-default-settings.patch into 6 new patches.
- Added 2.4-QT5.5-compat.patch (compatibility patch for OpenSUSE Leap 42.1, which uses QT 5.5).
- Removed calamares-opensuse-default-settings.patch.
* Mon Jun  6 2016 egeorget@openmailbox.org
- Updated to Calamares 2.2.3
